==> messagehub-sdk-job-1.0-20241120.050928-14-sources.jar: com/ovopark/messagehub/sdk/job/ClientNodeRegisterImpl.java <==
package com.ovopark.messagehub.sdk.job;

import com.ovopark.kernel.shared.JSONAccessor;
import com.ovopark.messagehub.sdk.internal.MessageHubJobApi;
import com.ovopark.messagehub.sdk.model.internal.job.ClientNodeRegisterRequest;
import com.ovopark.messagehub.sdk.model.internal.job.ClientNodeRegisterResponse;
import com.ovopark.module.shared.BaseResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;

import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

import static com.ovopark.kernel.shared.Util.schedule;

@Slf4j
@JobClientActive
@Component
public class ClientNodeRegisterImpl implements ClientNodeRegister, CommandLineRunner {

    @Autowired
    private ClientNodeProvider clientNodeProvider;

    final static ScheduledExecutorService scheduledExecutorService= Executors.newScheduledThreadPool(1);

    @Autowired
    MessageHubJobApi messageHubJobApi;

    @Override
    public void register() {
        schedule(scheduledExecutorService, () -> {

            ClientNode clientNode = clientNodeProvider.clientNode();
            ClientNodeRegisterRequest clientNodeRegisterRequest=new ClientNodeRegisterRequest();
            clientNodeRegisterRequest.setApp(clientNode.app());
            clientNodeRegisterRequest.setNode(clientNode.node());
            clientNodeRegisterRequest.setIp(clientNode.ip());
            clientNodeRegisterRequest.setPort(clientNode.port());
            clientNodeRegisterRequest.setServletPath(clientNode.servletPath());

            BaseResult<ClientNodeRegisterResponse> baseResult = messageHubJobApi.heartbeat(clientNodeRegisterRequest);
            if (baseResult == null || baseResult.getIsError()) {
                log.info(JSONAccessor.impl().format(baseResult));
            }

        },5, TimeUnit.SECONDS, e->{
            log.error(e.getMessage());
            return true;
        },()->true);
    }

    @Override
    public void run(String... args) throws Exception {
        register();
    }
}

==> messagehub-sdk-job-1.0-20250917.070109-42-sources.jar: com/ovopark/messagehub/sdk/job/ClientNodeRegisterImpl.java <==
package com.ovopark.messagehub.sdk.job;

import com.ovopark.kernel.shared.JSONAccessor;
import com.ovopark.kernel.shared.vclient.ClientNode;
import com.ovopark.kernel.shared.vclient.ClientNodeRegister;
import com.ovopark.messagehub.sdk.internal.MessageHubJobApi;
import com.ovopark.messagehub.sdk.model.internal.job.ClientNodeRegisterRequest;
import com.ovopark.messagehub.sdk.model.internal.job.ClientNodeRegisterResponse;
import com.ovopark.module.shared.BaseResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;

import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

import static com.ovopark.kernel.shared.Util.schedule;

@Slf4j
@JobClientActive
@Component
public class ClientNodeRegisterImpl implements ClientNodeRegister, CommandLineRunner {

    @Autowired
    private com.ovopark.messagehub.sdk.job.ClientNodeProvider clientNodeProvider;

    final static ScheduledExecutorService scheduledExecutorService= Executors.newScheduledThreadPool(1);

    @Autowired
    MessageHubJobApi messageHubJobApi;

    @Override
    public void register() {
        schedule(scheduledExecutorService, () -> {

            ClientNode clientNode = clientNodeProvider.clientNode();
            ClientNodeRegisterRequest clientNodeRegisterRequest=new ClientNodeRegisterRequest();
            clientNodeRegisterRequest.setApp(clientNode.app());
            clientNodeRegisterRequest.setNode(clientNode.node());
            clientNodeRegisterRequest.setIp(clientNode.ip());
            clientNodeRegisterRequest.setPort(clientNode.port());
            clientNodeRegisterRequest.setServletPath(clientNode.servletPath());

            BaseResult<ClientNodeRegisterResponse> baseResult = messageHubJobApi.heartbeat(clientNodeRegisterRequest);
            if (baseResult == null || baseResult.getIsError()) {
                log.info(JSONAccessor.impl().format(baseResult));
            }

        },5, TimeUnit.SECONDS, e->{
            log.error(e.getMessage());
            return true;
        },()->true);
    }

    @Override
    public void run(String... args) throws Exception {
        register();
    }
}
